@@ -1,3 +1,5 @@
+use crate::{player_info::PlayerInfo, q3_error::Q3Error};
+
 use super::player_list::PlayerList;
 use std::collections::HashMap;
 
@@ -16,14 +18,14 @@ pub struct ServerInfo {
     /// sv_hostname: ^7|^1RFA^7| ^2RisenFromAshes.us
     /// sv_maxPing: 0
     /// ```
-    pub vars: HashMap<String, String>,
-    pub players: PlayerList,
+    vars: HashMap<String, String>,
+    players: PlayerList,
 }
 
 impl ServerInfo {
-    pub fn new(raw: &str) -> Self {
-        let (server_raw, player_raw) = raw.split_once("\n").unwrap();
-        let players = PlayerList::new(player_raw);
+    pub fn new(raw: &str) -> Result<Self, Q3Error> {
+        let (server_raw, player_raw) = raw.split_once("\n").unwrap_or_default();
+        let players = PlayerList::new(player_raw)?;
 
         let mut vars: HashMap<String, String> = HashMap::new();
         let mut server_raw = server_raw.split("\\");
@@ -40,6 +42,14 @@ impl ServerInfo {
             }
         }
 
-        Self { vars, players }
+        Ok(Self { vars, players })
+    }
+
+    pub fn vars(&self) -> &HashMap<String, String> {
+        &self.vars
+    }
+
+    pub fn players(&self) -> &Vec<PlayerInfo> {
+        &self.players.0
     }
 }
